

error_response = '''<eSummaryResult>
<DocumentSummarySet status="OK">
<DbBuild>Build141124-1357.1</DbBuild>
<DocumentSummary uid="3">
<error>cannot get document summary</error>
</DocumentSummary>
</DocumentSummarySet>
</eSummaryResult>'''

